#
# spec file for package libqca-qt5
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _so 2
%bcond_without pkcs11
Name:           libqca-qt5
Version:        2.3.0
Release:        bp153.2.2.1
Summary:        Qt Cryptographic Architecture 2
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://userbase.kde.org/QCA
Source:         https://download.kde.org/stable/qca/%{version}/qca-%{version}.tar.xz
Source99:       libqca-qt5-rpmlintrc
# PATCH-FIX-OPENSUSE
Patch0:         qca-2.3.0-fixDSA.patch
BuildRequires:  ca-certificates
BuildRequires:  cmake >= 3.4
BuildRequires:  cyrus-sasl-devel
BuildRequires:  gpg2
BuildRequires:  libdrm-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libjpeg-devel
BuildRequires:  mozilla-nss-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core) >= 5.6.0
BuildRequires:  pkgconfig(Qt5Network) >= 5.6.0
BuildRequires:  pkgconfig(openssl)
Requires:       gpg2 >= 2.0.0
Recommends:     %{name}-plugins
Provides:       libqca-qt5-2 = %{version}
Obsoletes:      libqca-qt5-2 < %{version}
%if %{with pkcs11}
BuildRequires:  pkcs11-helper-devel
%endif

%description
This package provides a generic Qt cryptographic architecture,
including a library and a plug-in for using all supported capabilities
of openssl, like SSL/TLS, X509, RSA, SHA1, MD5, Blowfish, 3DES, and
AES.

It can be extended by further plug-ins, for example, with qca-sasl for
SASL support.

%package devel
Summary:        Development files for the Qt Cryptographic Architecture 2
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       pkgconfig(Qt5Core) >= 5.6.0
Requires:       pkgconfig(Qt5Network) >= 5.6.0

%description devel
This package provides a generic Qt cryptographic architecture,
including a library and a plugin for using all supported capabilities
of openssl, like SSL/TLS, X509, RSA, SHA1, MD5, Blowfish, 3DES and AES.

%package plugins
Summary:        Various plugins for the Qt Cryptographic Architecture 2
Group:          System/Libraries

%description plugins
This package provides a generic Qt cryptographic architecture,
including a library and a plug-in for using all supported capabilities
of openssl, like SSL/TLS, X509, RSA, SHA1, MD5, Blowfish, 3DES, and
AES.

It can be extended by further plug-ins, for example, with qca-sasl for
SASL support.

%prep
%setup -q -n qca-%{version}
%patch0 -p1

%build
%cmake \
      -DBUILD_TESTS=OFF \
      -DQCA_INSTALL_IN_QT_PREFIX=ON \
      -DWITH_botan_PLUGIN=OFF \
      -DQCA_BINARY_INSTALL_DIR:PATH="%{_bindir}" \
      -DQCA_MAN_INSTALL_DIR:PATH="%{_mandir}" \
      -DQCA_SUFFIX=qt5
make %{?_smp_mflags}

%install
%cmake_install

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license COPYING
%doc README TODO
%{_libdir}/libqca-qt5.so.*
%dir %{_libdir}/qt5/plugins/crypto
%{_libdir}/qt5/plugins/crypto/libqca-logger.so
%{_libdir}/qt5/plugins/crypto/libqca-softstore.so
%{_libdir}/qt5/plugins/crypto/libqca-ossl.so
%{_libdir}/qt5/plugins/crypto/libqca-gnupg.so
%{_libdir}/qt5/plugins/crypto/libqca-gcrypt.so

%files devel
%{_bindir}/qcatool-qt5
%{_bindir}/mozcerts-qt5
%{_includedir}/qt5/Qca-qt5/
%{_libdir}/qt5/mkspecs/features/crypto.prf
%{_mandir}/man1/qcatool-qt5.1%{?ext_man}
%{_libdir}/libqca-qt5.so
%{_libdir}/pkgconfig/qca2-qt5.pc
%{_libdir}/cmake/Qca-qt5/

%files plugins
%{_libdir}/qt5/plugins/crypto/libqca-cyrus-sasl.so
%{_libdir}/qt5/plugins/crypto/libqca-nss.so
%if %{with pkcs11}
%{_libdir}/qt5/plugins/crypto/libqca-pkcs11.so
%endif

%changelog
* Tue Mar 10 2020 Antonio Larrosa <alarrosa@suse.com>
- Remove baselibs.conf
* Wed Feb 26 2020 Wolfgang Bauer <wbauer@tmo.at>
- Update to 2.3.0
  * Qt5 is the only supported Qt series now
  * OpenSSL <= 1.1.0 is no longer supported
  * Various botan bugfixes
  * More dynamic test coverage of backend capabilities
  * no longer tries to setuid when the effective uid is not root
- Rename qca-2.2.1-fixDSA.patch to qca-2.3.0-fixDSA.patch and
  rebase it
- Update minimum required Qt5 and cmake versions
* Mon Sep  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Drop the obsolete libqca2 package.
- Run spec-cleaner
* Fri Apr 26 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Fix source URL
* Fri Apr 26 2019 Wolfgang Bauer <wbauer@tmo.at>
- Update to 2.2.1
  * support for openssl 1.1
  * support for AES GCM and AES CCM modes
  * new base64 convenience functions
  * new botan2 support
  * new hkdf support
  * various build improvements and (deprecation) cleanups
- Drop patches merged upstream:
  * 0001-Revert-tlsunittest-disable-some-ciphers.patch
  * 0002-Disable-missed-openssl-cipher-suites.patch
  * 0003-Add-support-for-OpenSSL-1.1.0.patch
  * ansi.diff
- Rename qca-2.1.3-fixDSA.patch to qca-2.2.1-fixDSA.patch and
  rebase it
- Re-enable pkcs11, there is no openssl conflict anymore
- Don't hardcode the certstore path anymore, ca-certificates is
  BuldRequired so this can be detected automatically
* Thu Oct 25 2018 Jason Sikes <jsikes@suse.de>
- Fix segfault when creating DSA keys
  * [qca-2.1.3-fixDSA.patch]
  * bsc#1108634
* Wed Dec 27 2017 jengelh@inai.de
- Diversify subpackage descriptions.
* Wed Dec 20 2017 fabian@ritter-vogt.de
- Add patches to support OpenSSL 1.1.0:
  * 0001-Revert-tlsunittest-disable-some-ciphers.patch
  * 0002-Disable-missed-openssl-cipher-suites.patch
  * 0003-Add-support-for-OpenSSL-1.1.0.patch
- Fix provides in main package
* Thu Oct 19 2017 meissner@suse.com
- buildignore openssl-1_0_0 to avoid conflicts during the
  openssl 1.1 effort.
* Mon Oct  9 2017 vcizek@suse.com
- Hardcode certstore path on Tumbleweed, in order to avoid
  BuildRequires: ca-certificates, which will create a conflict,
  because it requires openssl-1_1_0 (bsc#1055310)
* Sun Oct  1 2017 wbauer@tmo.at
- Update to 2.1.3
  * No changelog provided
- Drop libqca-qt5-2.1.1-explicit-signed-char.patch, merged upstream
- Update Url
* Fri Sep 29 2017 wbauer@tmo.at
- Remove libbotan-devel build requirement, we explicitly disable
  building the botan plugin anyway (boo#1055322)
* Fri Aug 25 2017 fvogt@suse.com
- Force building against openSSL 1.0 (boo#1055310)
- Disable PKCS11 on TW to avoid openssl conflicts
* Wed May 25 2016 antoine.belvire@laposte.net
- Fix build on PowerPC with GCC 6:
  * Add libqca-qt5-2.1.1-explicit-signed-char.patch
* Sat Oct  3 2015 hrvoje.senjan@gmail.com
- Update to 2.1.1
  * No changelog provided
- Drop Use-Q_SLOTS-Q_SIGNALS.patch and 0001-Add-missing-QIODevice-include.patch
* Sat Sep 26 2015 hrvoje.senjan@gmail.com
- Added Use-Q_SLOTS-Q_SIGNALS.patch from upstream: allow building
  without QT_NO_KEYWORDS define
* Sat Jan 10 2015 hrvoje.senjan@gmail.com
- Update to 2.1.0.3
  * Allow co-installability with Qt4 build
- Remove conflict with libqca2-devel
- Bump required cmake version to 2.8.12
- Added ansi.diff, rh#1182200
- Added 0001-Add-missing-QIODevice-include.patch, fixes build with
  Qt 5.5
* Sat Nov  8 2014 hrvoje.senjan@gmail.com
- Update to 2.1.0
  * Ported to Qt5 (Qt4 alsa supported)
  * New building system. CMake instead of qmake
  * Added CTR symetric cipher support to qca core
  * Added no padding encryption algorithm to qca core
  * qcatool2 renamed to qcatool
  * fixed crash in qcatool when only options provided on command
    line without any commands
  * Use plugins installation path as hard-coded runtime plugins
    search path
  * Added new functiion pluginPaths
  * Added functions to get runtime QCA version
  * Fixed 'no watch file' warnings in FileWatch
  * Added EME_PKCS1v15_SSL Encryption Algorithm
  * New implementation of SafeTimer to prevent crashes
  * Updated certificates for unittests
  * RSA Keys are permutable, can encrypt with private
    and decrypt with public
  * Add unloadProvider() function for symmetry
    with insertProvider()
  * Overloaded "makeKey" to derive a password depending
    on a time factor
  * Remove pointer to deinit() routine from QCoreApplication
    at deinitialization
  * Fix a couple of crashes where all plugins
    might not be available
  * Fix operating on keys with unrelated expired subkeys
  * Fixed timers in Synchronizer class
  * Dropped randomunittest
  * Fixed many unittests
  * qca-gnupg: internal refactoring
  * qca-gnupg: try both gpg and gpg2 to find gnupg executable
  * qca-gnupg: fixed some encodings problem
  * qca-ossl: no DSA_* dl groups in FIPS specification
  * qca-ossl: added missed signatures to CRLContext
  * qca-ossl: fixed certs time zone
  * qca-nss: fixed KeyLenght for Cipher
  * qca-botan: fixed getting result size for ciphers
* Thu Aug 14 2014 hrvoje.senjan@gmail.com
- Activate libqca-qt5 package
